"use client";

import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { Link, Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { getAdsData } from "@/utils/get-fake-data";
import { motion, useScroll, useTransform } from "framer-motion";
import Cookies from "js-cookie";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";
import { useEffect, useRef, useState } from "react";


export default function Ads() {
	const t = useTranslations();
	const locale = useLocale() as Locale;
	const [data, setData] = useState<any>(null);
	const isRTL = locale === "ar";

	const { texts } = useBasicInfo();
	const container = useRef<HTMLElement | null>(null);
	const [isLoggin, setIsLoggin] = useState(false);

	const { scrollYProgress } = useScroll({
		target: container,
		offset: ["start end", "end start"],
	});

	const y = useTransform(scrollYProgress, [0, 1], ["-10%", "10%"]);

	useEffect(() => {
		async function fetchData() {
			const adsData = await getAdsData();
			setData(adsData);
		}
		fetchData();

		const __success = Cookies.get("__t") !== undefined;
		setIsLoggin(__success);

	}, []);

	if (!data) {
		return <div>Loading...</div>;
	}

	return (
		<div
			ref={container as React.RefObject<HTMLDivElement>}
			className="relative flex h-screen items-center justify-center overflow-hidden md:h-[534px]"
			style={{ clipPath: "polygon(0% 0, 100% 0%, 100% 100%, 0 100%)" }}
		>
			<div className="relative mx-auto flex h-full min-h-[400px] w-full max-w-[1380px] items-center sm:min-h-[500px] lg:min-h-[600px]">
				<div className="relative grid w-full grid-cols-1 gap-6 px-4 md:grid-cols-12 md:gap-8 md:px-8 lg:px-12">
					{/* Discount Badge */}
					<div
						className={cn(
							"flex items-center justify-center py-4 md:col-span-5 md:p-8",
							isRTL ? "md:order-last" : "md:order-first"
						)}
					>
						<div className="relative h-32 w-32 sm:h-36 sm:w-36 md:h-40 md:w-40 lg:h-44 lg:w-44">
							<Image
								fill
								src={data.images.offerBadge}
								alt="offer-background"
								className="z-50 drop-shadow-lg"
							/>
							<div className="absolute inset-0 z-50 flex flex-col items-center justify-center text-white">
								<div className="text-lg font-medium sm:text-xl">
									{data.badge.text?.[locale]}
								</div>
								<span className="text-4xl font-bold sm:text-5xl">
									{data.badge.discount}
								</span>
							</div>
						</div>
					</div>

					{/* text container */}
					<div
						className={cn(
							"md:col-span-7",
							isRTL ? "items-end text-right" : "items-start text-left"
						)}
					>
						<div className="relative z-10 w-full max-w-2xl rounded-lg bg-[#1E1E1E96] px-[42px] py-[18px]">
							<ContentLines
								padding="none"
								title={data.content.subtitle?.[locale]}
							/>
							<h3 className="mb-8 mt-14 text-2xl font-normal leading-[48px] text-custom-background-light sm:mb-6 sm:text-3xl md:text-4xl">
								{texts?.simulation_program_section_title?.[locale]}
							</h3>
							<p className="mb-[52px] text-justify text-base font-normal leading-relaxed text-white">
								{texts.simulation_program_section_description?.[locale]}
							</p>
							<div
								className={cn(
									"flex w-full flex-col gap-4 sm:flex-row",
									isRTL ? "sm:flex-row" : "sm:flex-row-reverse"
								)}
							>
								<Button
									className="relative z-10 w-full bg-blue-500 px-4 py-4 text-sm font-medium hover:bg-blue-600 sm:w-auto sm:px-6 sm:py-5 md:px-8 md:py-6 md:text-base"
									asChild
								>
									<Link href={isLoggin ? "/simulation-program" as any : "/login" as any}>{t("Try Now")}</Link>
								</Button>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div className="fixed left-0 top-0 h-screen w-full">
				<motion.div style={{ y }} className="relative h-full w-full">
					<Image
						src={data.images.background}
						fill
						alt="image"
						style={{ objectFit: "cover" }}
					/>
				</motion.div>
			</div>
		</div>
	);
}
